Change Log
==========

A log of changes by version and date.

======= ========== =====
Version Date       Notes
======= ========== =====
1.0.0   05/15/2023 Initial Version
1.0.1   05/15/2023 Fixing the typo bugs
1.0.2   05/18/2023 Add Volume eradicate feature and map raw volume
1.0.3   05/19/2023 Add Shell scripts
1.0.4   05/19/2023 Fixing permissions of the files
1.0.6   05/20/2023 Fixing Grammer
1.0.7   05/22/2023 Adding unmap Shell script
======= ========== =====